@@ -20,6 +20,8 @@
 /*											*/
 /****************************************************************************************/
 
+// LVIFIX: this source file is not 7-bit clean, see NABCExport::lyrics2ABC(..
+
 #include <qstring.h>
 #include <qregexp.h>
 #include <qspinbox.h>
@@ -497,6 +499,9 @@ bool NABCExport::writeFirstVoice(NVoice *voice_elem, QString staffName, int staf
 					writeChord(diag);
 				     }
 				     writePendingSigns(idx);
+				     if (rest->status_ & STAT_FERMT) {
+					out_ << "!fermata!";
+				     }
 				     if (rest->getSubType() == MULTIREST) {
 				     	out_ << 'Z';
 					len = rest->getMultiRestLength() * QUARTER_LENGTH;
@@ -638,7 +643,7 @@ bool NABCExport::writeOtherVoicesTill(int staff_nr, int voice_nr, QString staffN
 
 	if (!elem || elem->midiTime_ >= stopTime) return false;
 	actual_staff->resetSpecialElement();
-	actual_staff->syncSpecialElement(elem->getXpos());
+	//actual_staff->syncSpecialElement(elem->getXpos());	// removed for FIX #3505
 	idx = voice_elem->getIdx();
 
 	out_ << "[V: " << createVoiceName(staffName, staff_nr, voice_nr) << "] ";
@@ -746,7 +751,9 @@ bool NABCExport::writeOtherVoicesTill(int staff_nr, int voice_nr, QString staffN
 					out_ << '}';
 				     }
 				     if (!inTuplet) out_ << ' ';
-
+				     if (rest->status_ & STAT_FERMT) {
+					out_ << "!fermata!";
+				     }
 				     if (rest->getSubType() == MULTIREST) {
 				     	out_ << 'Z';
 					len = rest->getMultiRestLength() * QUARTER_LENGTH;
@@ -1140,6 +1147,10 @@ void NABCExport::outputVoiceParams(NVoice *voice, QString staffName) {
 	out_ << ' ';
 
 	if (!staffName.isEmpty()) {
+		staffName.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
+		staffName.replace ('\n', "\\n"); /* replace all newlines with \n two character symbols */
+		staffName.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */	
+
 		out_ << "name=\"" << staffName << '"';
 	}
 }
@@ -1149,6 +1160,7 @@ bool NABCExport::outputClefInfo(NClef *clef) {
 	switch (clef->getSubType()) {
 		case TREBLE_CLEF: out_ << "clef=treble"; break;
 		case BASS_CLEF: out_ << "clef=bass"; break;
+		case SOPRANO_CLEF: out_ << "clef=alto1"; break;
 		case ALTO_CLEF: out_ << "clef=alto"; break;
 		case TENOR_CLEF: out_ << "clef=alto4"; break;
 		case DRUM_CLEF: out_ << "clef=perc"; break;
