@@ -31,6 +31,7 @@
 #include <istream.h>
 #endif
 #include <stdlib.h> //  esigra: needed for mkstemp when --without-libs
+#include <stdio.h>  //  for test only
 #include <kfiledialog.h>
 #include <kmessagebox.h>
 #include <klocale.h>
@@ -67,6 +68,12 @@
 #define LILY_ERR_PIANO_DISCONT     9
 #define LILY_ERR_CONT_OUTSIDE     10
 
+// Bitpositions used in scoreBraceMasks
+#define BRACE_START	(1 << 0)
+#define BRACE_END	(1 << 1)
+#define BRACKET_START	(1 << 2)
+#define BRACKET_END	(1 << 3)
+
 #define MEASURES_PER_LINE 2
 
 #define EDGE_TEXT_NOT_SET 0
@@ -88,6 +95,7 @@ NLilyExport::NLilyExport() {
 	os_ = new ostrstream(buffer_, 128);
 #endif
 	noStrongPizzMsg_ = false;
+	scoreBlock.setAutoDelete( TRUE );
 }
 
 void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFrm *expWin, NMainFrameWidget *mainWidget) {
@@ -147,6 +155,11 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 	out_ << "%           \"noteedit\"             %" << endl;
 	out_ << "%                                  %" << endl;
 	out_ << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << endl << endl;
+	if (NResource::lilyProperties_.lilyVersion24) {
+    	out_ << "\\version \"2.4.2\"" << endl << endl;		// LilyPond version 2.4.2 is the one that it is tested with.
+	} else {
+    	out_ << "\\version \"2.0\"" << endl << endl;        // We currently support LilyPond version 2.0 syntax for sure. We must mention this in order to make convert-ly working.
+	}
 	if (!exportDialog_->lilyVoice->isChecked()) {
 		if (NResource::lilyProperties_.lilyProperties) {
 			out_ << "\\include \"paper" << exportDialog_->lilyFont->currentText() << ".ly\"" << endl << endl;
@@ -156,7 +169,12 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 		}
 	}
 	if (exportDialog_->lilyDrumNotes->isChecked()) {
-		if (NResource::lilyProperties_.lilyProperties) {
+		if (NResource::lilyProperties_.lilyVersion24) {
+			out_ << "bcr = { \\override Voice.NoteHead #'style = #'cross" << endl << '}' << endl;
+			out_ << "bdf = { \\override Voice.NoteHead #'style = #'default" << endl << '}' << endl;
+			out_ << "bcc = { \\override Voice.NoteHead #'style = #'xcircle" << endl << '}' << endl;
+			out_ << "btr = { \\override Voice.NoteHead #'style = #'triangle" << endl << '}' << endl << endl;
+		} else if (NResource::lilyProperties_.lilyProperties) {
 			out_ << "bcr = {" << endl << "\\context Thread = xcircle" << endl << "\\property Voice.NoteHead \\set #'style = #'cross" << endl << '}' << endl;
 			out_ << "bdf = {" << endl << "\\context Thread = xdefault" << endl << "\\property Voice.NoteHead \\set #'style = #'default" << endl << '}' << endl;
 			out_ << "bcc = {" << endl << "\\context Thread = xcircle" << endl << "\\property Voice.NoteHead \\set #'style = #'xcircle" << endl << '}' << endl;
@@ -183,12 +201,18 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 	out_ << endl;
 
 
+	QString outString;
 	if (!mainWidget->scTitle_.isEmpty() && !mainWidget->scTitle_.isNull()) {
 		if (!header_written) {
 			header_written = true;
 			out_ << endl << "\\header {" << endl;
 		}
-		out_ << "\ttitle = \"" << mainWidget->scTitle_ << '"';
+		outString = mainWidget->scTitle_;
+		outString.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
+		outString.replace ('\n', "\\n"); /* replace all newlines with \n two character symbols */
+		outString.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
+
+		out_ << "\ttitle = \"" << outString << '"';
 		if (NResource::lilyProperties_.lilySemicolons) out_ << ";";
 		out_ << endl;
 	}
@@ -197,7 +221,12 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 			header_written = true;
 			out_ << endl << "\\header {" << endl;
 		}
-		out_ << "\tcomposer = \"" << mainWidget->scAuthor_ << '"';
+		outString = mainWidget->scAuthor_;
+		outString.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
+		outString.replace ('\n', "\\n"); /* replace all newlines with \n two character symbols */
+		outString.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
+		
+		out_ << "\tcomposer = \"" << outString << '"';
 		if (NResource::lilyProperties_.lilySemicolons) out_ << ";";
 		out_ << endl;
 	}
@@ -206,13 +235,19 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 			header_written = true;
 			out_ << endl << "\\header {" << endl;
 		}
-		out_ << "\tcopyright = \"" << mainWidget->scCopyright_ << '"';
+		outString = mainWidget->scCopyright_;
+		outString.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
+		outString.replace ('\n', "\\n"); /* replace all newlines with \n two character symbols */
+		outString.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
+		
+		out_ << "\tcopyright = \"" << outString << '"';
 		if (NResource::lilyProperties_.lilySemicolons) out_ << ";";
 		out_ << endl;
 	}
 	if (header_written) {
 		out_ << '}' << endl << endl;
 	}
+	buildBraceMasks(stafflist, mainWidget);
 	for (i = 0, staff_elem = stafflist->first(); staff_elem; staff_elem = stafflist->next(), i++) {
 		if (!staffarray_[i].is_selected) continue; 
 		voice_count = staff_elem->voiceCount();
@@ -225,16 +260,26 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 			}
 			removeExceptsFromString(&staffLabel, false);
 			out_ << staffLabel;
-			out_ << " = \\notes\\relative c";
+			if (NResource::lilyProperties_.lilyVersion24) {
+				out_ << " = \\relative c";
+			} else {
+				out_ << " = \\notes\\relative c";
+			}
 			voice_elem = staff_elem->getVoiceNr(0);
 			clef = voice_elem->getFirstClef();
 			switch (clef->getSubType()) {
 				case DRUM_BASS_CLEF:
 				case DRUM_CLEF: lastLine_ = -3; str = 0; break;
-				case TENOR_CLEF: lastLine_ = 3; str = 1; break;
+				case SOPRANO_CLEF: lastLine_ = 6; str = 2;
+						if (NResource::lilyProperties_.lilyVersion24 && clef->getShift() == -12) str = 1;
+						if (NResource::lilyProperties_.lilyVersion24 && clef->getShift() ==  12) str = 3;
+														break;
 				case ALTO_CLEF: lastLine_ = 4; str = 1; break;
+				case TENOR_CLEF: lastLine_ = 3; str = 1; break;
 				case BASS_CLEF: lastLine_ = 3; str = 0; break;
-				case TREBLE_CLEF: lastLine_ = -2; str = 1; break;
+				case TREBLE_CLEF: lastLine_ = -2; str = 1;			// violin clef lowered an octave?
+						if (NResource::lilyProperties_.lilyVersion24 && clef->getShift() == -12) str = 0;
+														break;
 			} 
 			for (k = 0; k < str; k++) out_ << '\'';
 			out_ << " {" << endl << '\t';
@@ -255,11 +300,15 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 				}
 			}
 			if (!voice_elem->getStaff()->staffName_.isNull() && !voice_elem->getStaff()->staffName_.isEmpty()) {
+				outString = voice_elem->getStaff()->staffName_;
+				outString.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
+				outString.replace ('\n', "\\n"); /* replace all newlines with \n two character symbols */
+				outString.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
 				if (NResource::lilyProperties_.lilyProperties) {
-					out_ << "\\property Staff.instrument = #\"" << staff_elem->staffName_ << '"' << endl << '\t';
+					out_ << "\\property Staff.instrument = #\"" << outString << '"' << endl << '\t';
 				}
 				else {
-					out_ << "\\set Staff.instrument = #\"" << staff_elem->staffName_ << '"' << endl << '\t';
+					out_ << "\\set Staff.instrument = #\"" << outString << '"' << endl << '\t';
 				}
 			}
 			voice_elem->prepareForWriting();
@@ -281,23 +330,33 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 				}
 				removeExceptsFromString(&staffLabel, false);
 				out_ << staffLabel;
-				out_ << " = \\notes\\relative c";
+				if (NResource::lilyProperties_.lilyVersion24) {
+					out_ << " = \\relative c";
+				} else {
+					out_ << " = \\notes\\relative c";
+				}
 				switch (clef->getSubType()) {
 					case DRUM_BASS_CLEF:
 					case DRUM_CLEF: lastLine_ = -3; str = 0; break;
-					case TENOR_CLEF: lastLine_ = 3; str = 1; break;
+					case SOPRANO_CLEF: lastLine_ = 6; str = 2;
+						if (NResource::lilyProperties_.lilyVersion24 && clef->getShift() == -12) str = 1;
+						if (NResource::lilyProperties_.lilyVersion24 && clef->getShift() ==  12) str = 3;
+															break;
 					case ALTO_CLEF: lastLine_ = 4; str = 1; break;
+					case TENOR_CLEF: lastLine_ = 3; str = 1; break;
 					case BASS_CLEF: lastLine_ = 3; str = 0; break;
-					case TREBLE_CLEF: lastLine_ = -2; str = 1; break;
+					case TREBLE_CLEF: lastLine_ = -2; str = 1;			// violin clef lowered an octave?
+							if (NResource::lilyProperties_.lilyVersion24 && clef->getShift() == -12) str = 0;
+															break;
 				} 
 				for (k = 0; k < str; k++) out_ << '\'';
-				out_ << " {";
+                out_ << " {" << endl << '\t';
 				if (!(exportDialog_->lilyStem->isChecked())) {
 					switch(j) {
-						case 0: out_ << " \\voiceOne "; break;
-						case 1: out_ << " \\voiceTwo "; break;
-						case 2: out_ << " \\voiceThree "; break;
-						case 3: out_ << " \\voiceFour "; break;
+						case 0: out_ << "\\voiceOne "; break;
+						case 1: out_ << "\\voiceTwo "; break;
+						case 2: out_ << "\\voiceThree "; break;
+						case 3: out_ << "\\voiceFour "; break;
 					}
 				}
 				out_ <<  endl << '\t';
@@ -331,13 +390,18 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 				staffLabel = staff_elem->staffName_ + s.sprintf("%c", i + 'A');
 			}
 			removeExceptsFromString(&staffLabel, false);
+
 			out_ << staffLabel << " = \\simultaneous {" << endl;
 			if (!staff_elem->staffName_.isNull() && !staff_elem->staffName_.isEmpty()) {
+				outString = staff_elem->staffName_;
+				outString.replace('\\', "\\\\"); /* replace all backslashes with \\ two character backslashes */
+				outString.replace ('\n', "\\n"); /* replace all newlines with \n two character symbols */
+				outString.replace('"', "\\\""); /* replace all double quotes with \" two character symbols */
 				if (NResource::lilyProperties_.lilyProperties) {
-					out_ << "\t\\property Staff.instrument = #\"" << staff_elem->staffName_ << '"' << endl;
+					out_ << "\t\\property Staff.instrument = #\"" << outString << '"' << endl;
 				}
 				else {
-					out_ << "\t\\set Staff.instrument = #\"" << staff_elem->staffName_ << '"' << endl;
+					out_ << "\t\\set Staff.instrument = #\"" << outString << '"' << endl;
 				}
 			}
 			for (j = 0, voice_elem = staff_elem->getVoiceNr(0); j < voice_count; j++) {
@@ -360,11 +424,21 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 		}
 		removeExceptsFromString(&staffLabel, false);
 		if (staffarray_[i].lyrics_count) {
-			out_ << staffLabel << "Text = \\lyrics ";
-			writeLyrics(i, voice_elem);
+			if (NResource::lilyProperties_.lilyVersion24) {
+				//out_ << staffLabel << "Text = \\lyricmode ";
+			} else {
+				out_ << staffLabel << "Text = \\lyrics ";
+			}
+			writeLyrics(i, voice_elem, staffLabel);
 		}
-	}
-	if (!exportDialog_->lilyVoice->isChecked()) {
+		if (NResource::lilyProperties_.lilyVersion24)
+			buildScoreBlockAndFlush(i, staff_elem, staffLabel, stafflist, scoreBraceMasks, false);
+	} // end for (i = 0, staff_elem = stafflist->first(); ...
+	
+	if (NResource::lilyProperties_.lilyVersion24)
+		buildScoreBlockAndFlush(0, NULL, "", stafflist, scoreBraceMasks, true);
+
+	if (!exportDialog_->lilyVoice->isChecked() && !NResource::lilyProperties_.lilyVersion24) {
 		out_ << "\\score {" << endl;
 		out_ << "\t\\simultaneous {" << endl;
 		if (NResource::lilyProperties_.lilyProperties) {
@@ -373,12 +447,16 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 		else {
 			out_ << "\t\t\\set Score.skipBars = ##t" << endl;
 		}
-		if (NResource::lilyProperties_.lilyVersion2) {
-			if (NResource::lilyProperties_.lilyProperties) {
-				out_ << "\t\t\\property Score.melismaBusyProperties = #'(melismaBusy slurMelismaBusy tieMelismaBusy)" << endl;
-			}
-			else {
-				out_ << "\t\t\\set Score.melismaBusyProperties = #'(melismaBusy slurMelismaBusy tieMelismaBusy)" << endl;
+		if (NResource::lilyProperties_.lilyVersion24) {
+			out_ << "\t\t\\set Score.melismaBusyProperties = #'()" << endl;
+		} else {
+			if (NResource::lilyProperties_.lilyVersion2) {
+				if (NResource::lilyProperties_.lilyProperties) {
+					out_ << "\t\t\\property Score.melismaBusyProperties = #'(melismaBusy slurMelismaBusy tieMelismaBusy)" << endl;
+				}
+				else {
+					out_ << "\t\t\\set Score.melismaBusyProperties = #'(melismaBusy slurMelismaBusy tieMelismaBusy)" << endl;
+				}
 			}
 		}
 		depth_ = 2;
@@ -427,7 +505,11 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 				if (mainWidget->braceMatrix_[k].valid) {
 					if (mainWidget->braceMatrix_[k].beg == i) {
 						tabsOut();
-						out_ << "\\context PianoStaff \\notes" << endl;
+						if (NResource::lilyProperties_.lilyVersion24) {
+							out_ << "\\context PianoStaff" << endl;
+						} else {
+							out_ << "\\context PianoStaff \\notes" << endl;
+						}
 						if (NResource::lilyProperties_.lilyVersion2) {
 							out_ << "<< ";
 						}
@@ -459,7 +541,11 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 
 			tabsOut();
 			if (staffarray_[i].lyrics_count) {
-				out_ << "\\addlyrics " << endl; tabsOut();
+				if (NResource::lilyProperties_.lilyVersion24) {
+					out_ << "\\oldaddlyrics " << endl; tabsOut();
+				} else {
+					out_ << "\\addlyrics " << endl; tabsOut();
+				}
 			}
 	                out_ << "\\context Staff=\"" << staffName << "\" ";
 			out_ << '\\' << staffLabel << endl;
@@ -499,7 +585,11 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 	
 	
 		out_ << "\t}" << endl;
+		if (NResource::lilyProperties_.lilyVersion24) {
+	        out_ << "\t\\layout {" << endl;
+		} else {
 	        out_ << "\t\\paper {" << endl;
+		}
 		if (exportDialog_->lilyLand->isChecked()) {
 			out_ << "\t\torientation = \"landscape\"" << endl;
 			if (NResource::lilyProperties_.lilySemicolons) out_ << ";";
@@ -583,12 +673,12 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 
 
 void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
-	NMusElement *elem, *specialElem;
-	char *hiddenRepeat = "\\repeat \"volta\" 2 {";
+	NMusElement *elem, *elem2, *specialElem;
+	const char *hiddenRepeat = "\\repeat \"volta\" 2 {";
 	int total = 0, i;
 	bool first;
 	bool AfterFirstBar = false;
-	char *pendingVolSig = 0;
+	const char *pendingVolSig = 0;
 	int pending_tempo = -1;
 	unsigned int pending_segnos_rirads_accels = 0;
 #define PENDING_SEGNO		  (1 << 0)
@@ -628,9 +718,11 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 	int kind, count;
 	NStaff *actual_staff;
 	int dynEndPos = 0;
-	char *lastDynSym = 0;
+	const char *lastDynSym = 0;
 	bool textpropset = false;
-	bool fatTextWritten = false;
+	bool fatTextWritten = true;	// Text will not influence the horizontal spacing of notes
+	bool inLongacciaccatura = false;
+	bool inA_tura = false;
 	int edgetext = EDGE_TEXT_NOT_SET;
 	int trillendpos = 0;
 	int trilledNotes = 0;
@@ -639,6 +731,7 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 	int restlen;
 	int octaviation = 0;
 	NText *pending_text = 0;
+	bool drumNotesChange = true;	// not inside chords implemented, use different voices if needed.
 
 	countof128th_ = 128;
 	currentNumerator_ = currentDenominator_ = 4;
@@ -656,16 +749,29 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 	if (!voi->isFirstVoice()) {
 		actual_staff->resetSpecialElement();
 	}
+
 	do {
 		lastElemIsBar = false;
 		if (!voi->isFirstVoice()) {
+			// Handle relevant special elements (T_KEYSIG, T_CLEF and T_SIGN/BAR_SYM)
+			// between the previous and the current element.
+			// Note that special elements are all stored in the first voice.
 			while (specialElem = actual_staff->checkSpecialElement(elem->getXpos())) {
 				switch (specialElem->getType()) {
-					case T_KEYSIG: actual_staff->actualKeysig_.change((NKeySig *) specialElem); break;
+					case T_KEYSIG:
+						     actual_staff->actualKeysig_.change((NKeySig *) specialElem);
+						     break;
 					case T_CLEF: c4Line = actual_staff->actualClef_.lineOfC4();
 						     actual_staff->actualClef_.change((NClef *) specialElem);
 						     lastLine_ += actual_staff->actualClef_.lineOfC4() - c4Line;
-						     break; 
+						     break;
+					case T_SIGN: if (specialElem->getSubType() & BAR_SYMS) {
+							if (((++counter) % MEASURES_PER_LINE) == 0) {
+								out_ << "  % " << ((NSign *) specialElem)->getBarNr();
+								out_ << endl; tabsOut();
+							}
+						     }
+						     break;
 				}
 			}
 		}
@@ -806,10 +912,36 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 					if  (!inGrace) {
 						inGrace = true;
 						strokenGrace = true;
-						out_ << "\\grace { ";
-						if (elem->getSubType() != INTERNAL_MARKER_OF_STROKEN_GRACE) {
-							strokenGrace = false;
-							out_ << "[ ";
+						inA_tura = inLongacciaccatura = false;
+						if (/* NResource::lilyProperties_.lilyProperties || */ !(elem->status_ & STAT_SLURED)) {
+							out_ << "\\grace { ";
+							if (!NResource::lilyProperties_.lilyVersion2 && elem->getSubType() != INTERNAL_MARKER_OF_STROKEN_GRACE) {
+								strokenGrace = false;
+								out_ << "[ ";
+							}
+						}
+						else { // LilyPond-2.2.x
+							elem2 = voi->getNextPosition();
+							voi->getPrevPosition();
+							if (elem2->getType() == T_CHORD && !(elem2->status_ & STAT_GRACE)) {
+								if (elem->getSubType() == INTERNAL_MARKER_OF_STROKEN_GRACE) {
+									out_ << "\\acciaccatura ";
+								}
+								else {
+									out_ << "\\appoggiatura ";
+								}
+								inGrace = strokenGrace = false;
+								inA_tura = true;
+							}
+							else if (elem2->getType() == T_CHORD && elem->getSubType() == NOTE16_LENGTH && elem2->getSubType() == NOTE16_LENGTH &&
+								(elem->status_ & STAT_BEAMED) && (elem2->status_ & STAT_BEAMED)) {
+								out_ << "\\acciaccatura { ";
+								strokenGrace = false;
+								inLongacciaccatura = true;
+							}
+							else {
+								out_ << "\\grace { ";
+							}
 						}
 					}
 				     }
@@ -817,7 +949,7 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 					if (inGrace) {
 						slur_problem_written = false;
 						inGrace = false;
-						if (!strokenGrace) {
+						if (!strokenGrace && !NResource::lilyProperties_.lilyVersion2) {
 							strokenGrace = false;
 							out_ << "] ";
 						}
@@ -848,7 +980,12 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 						out_ << "#(set-octavation -1) ";
 					}
 				     }
-				     if (elem->getNoteList()->count() > 1) out_ << "< ";
+
+				     	if (elem->getNoteList()->count() > 1) {
+						out_ << "< ";
+						drumNotesChange = false;
+					}
+					
 				     first = true;
 			  	     for (note = elem->getNoteList()->first(); note; note = elem->getNoteList()->next()) {
 					     if (first) {
@@ -861,7 +998,7 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 						bad = new badmeasure(LILY_ERR_DRUM_STAFF, staff_nr +1, 3 /* dummy */, total / 3, countof128th_);
 						badlist_.append(bad);
 					     }
-					     if (exportDialog_->lilyDrumNotes->isChecked() && noteBody_ != (note->status & BODY_MASK)) {
+					     if (drumNotesChange && exportDialog_->lilyDrumNotes->isChecked() && noteBody_ != (note->status & BODY_MASK)) {
 						switch (noteBody_ = (note->status & BODY_MASK)) {
 							case STAT_BODY_CROSS:
 							case STAT_BODY_CROSS2:
@@ -914,7 +1051,7 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 							if (!noStrongPizzMsg_)
 								KMessageBox::sorry
 									(0,
-									 i18n("Sorry, strong Pizzicato is not available under LilyPoint. Take musixtex, to enjoy this feature."),
+                                     i18n("Sorry, strong Pizzicato is not available under LilyPond. Take musixtex, to enjoy this feature."),
 									 kapp->makeStdCaption(i18n("???"))
 									);
 							noStrongPizzMsg_ = true;
@@ -1038,12 +1175,14 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 						saveLine = lastLine_;
 					     }
 				     	     out_ << ' ';
-				     }
+				     } // end for (note = elem->getNoteList()->first() ...
 				     if (diag != 0) {
 					writeChordName(diag->getChordName());
 				     }
-				     if (elem->getNoteList()->count() > 1) {
-				     	out_ << "> ";
+					if (elem->getNoteList()->count() > 1) {
+				     		out_ << "> ";
+						drumNotesChange = true;
+					
 				        if (NResource::lilyProperties_.lilyVersion2 && (length != lastLength_ || lastDotted_ != (elem->status_ & DOT_MASK))) {
 						if (part == DOUBLE_WHOLE_LENGTH) {
 							out_ << "\\breve ";
@@ -1060,7 +1199,7 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 					        }
 				     }
 				     if (NResource::lilyProperties_.lilyVersion2) {
-					if (chord->status_ & STAT_SLURED) {
+					if ((chord->status_ & STAT_SLURED) && !inA_tura && !inLongacciaccatura) {
 					  		out_ << " ( ";
 					}
 					if (pendingVolSig) {
@@ -1114,10 +1253,15 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 						out_ << "^\\markup{\\large accel.} ";
 						pending_segnos_rirads_accels &= (~(PENDING_ACCELERANDO));
 					}
-					if (chord->status_ & STAT_PART_OF_SLUR) {
-						out_ << ") ";
+					if ((chord->status_ & STAT_PART_OF_SLUR) && !inLongacciaccatura) {
+						if (inA_tura) {
+							inA_tura = false;
+						}
+						else {
+							out_ << ") ";
+						}
 					}
-					if (!inGrace && exportDialog_->lilyBeam->isChecked()) {
+					if (exportDialog_->lilyBeam->isChecked() || inLongacciaccatura) {
 						if ((elem->status_ & STAT_BEAMED) && !inbeam) {
 							out_ << "[ "; inbeam = true;
 						}
@@ -1133,6 +1277,9 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 						lastDynSym = " \\! ";
 					}
 				     }
+				     if (hasATie(elem->getNoteList())) {
+					out_ << "~ ";
+				     }
 				     if (vaendpos != 0 && chord->getBbox()->right() > vaendpos) {
 					vaendpos = 0;
 					if (octaviation > 0) {
@@ -1144,14 +1291,14 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 					octaviation = 0;
 					out_ << "#(set-octavation 0) ";
 				     }
-				     if (exportDialog_->lilyBeam->isChecked()) {
+				     if (exportDialog_->lilyBeam->isChecked() || inLongacciaccatura) {
 				     	if (elem->lastBeamed()) {
 						out_ << "] "; inbeam = false;
 				     	}
 				     }
-				     if (hasATie(elem->getNoteList())) {
-					out_ << "~ ";
-				     }
+				     //if (hasATie(elem->getNoteList())) {
+				//	out_ << "~ ";
+				 //    }
 				     lastLine_ = saveLine;
 				     if (elem->status_ & STAT_LAST_TUPLET) {
 					intuplet = false;
@@ -1202,8 +1349,8 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 					out_ << "\\fatText ";
 				     }
 				     if (inGrace) {
-					inGrace = false;
-					if (!strokenGrace) {
+					inLongacciaccatura = inGrace = false;
+					if (!strokenGrace && !NResource::lilyProperties_.lilyVersion2) {
 						strokenGrace = false;
 						out_ << "] ";
 					}
@@ -1225,7 +1372,10 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 						}
 						pendingVolSig = 0;
 				     }
-				     if (NResource::lilyProperties_.lilyVersion2 && pending_tempo >= 0) {
+				     if (NResource::lilyProperties_.lilyVersion24 && pending_tempo >= 0) {
+					out_ << "    % FIXME, needs proper syntax: \\tempo 4.=" << pending_tempo << endl << ' ';
+					pending_tempo = -1;
+				     } else if (NResource::lilyProperties_.lilyVersion2 && pending_tempo >= 0) {
 					out_ << "\\tempo 4.=" << pending_tempo << ' ';
 					pending_tempo = -1;
 				     }
@@ -1256,7 +1406,10 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 				     		}
 						lastDotted_ = elem->status_ & DOT_MASK;
 				     	}
-				      }
+				     }
+				     if (elem->status_ & STAT_FERMT) {
+					out_ << "\\fermata";
+				     }
 				     if (!NResource::lilyProperties_.lilyVersion2) {
 					if (pendingVolSig) {
 						switch (exportDialog_->lilyVol->currentItem()) {
@@ -1350,11 +1503,11 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 			case T_KEYSIG: key = (NKeySig *) elem;
 				     prevElemIsBar = false;
 				     if (inGrace) {
-					inGrace = false;
-					if (!strokenGrace) {
+					if (!strokenGrace && !NResource::lilyProperties_.lilyVersion2) {
 						strokenGrace = false;
 						out_ << "] ";
 					}
+					inGrace = false;
 					out_ << "} ";
 				     }
 				     if (key->isRegular(&kind, &count)) {
@@ -1371,11 +1524,11 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 				     break;
 			case T_TIMESIG: timesig = (NTimeSig *) elem;
 					if (inGrace) {
-						inGrace = false;
-						if (!strokenGrace) {
+						if (!strokenGrace && !NResource::lilyProperties_.lilyVersion2) {
 							strokenGrace = false;
 							out_ << "] ";
 						}
+						inGrace = false;
 						out_ << "} ";
 					}
 					if (prevElemIsBar) {
@@ -1396,11 +1549,11 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 					out_ << endl; tabsOut();
 				     break;
 			case T_CLEF: if (inGrace) {
-					inGrace = false;
-					if (!strokenGrace) {
+					if (!strokenGrace && !NResource::lilyProperties_.lilyVersion2) {
 						strokenGrace = false;
 						out_ << "] ";
 					}
+					inGrace = false;
 					out_ << "} ";
 				     }
 				     clef = (NClef *) elem;
@@ -1408,9 +1561,25 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 			             out_ << "\\clef ";
 				     switch (clef->getSubType()) {
 					 case DRUM_CLEF:  out_ << "percussion"; if (NResource::lilyProperties_.lilySemicolons) out_ << ";"; break;
-				         case TREBLE_CLEF: out_ << "violin"; if (NResource::lilyProperties_.lilySemicolons) out_ << ";"; break;
-					 case TENOR_CLEF: out_ << "tenor"; if (NResource::lilyProperties_.lilySemicolons) out_ << ";"; break;
+					 case TREBLE_CLEF:
+											if (NResource::lilyProperties_.lilyVersion24) {
+												if (clef->getShift()== -12) {
+													out_ << "\"G_8\""; if (NResource::lilyProperties_.lilySemicolons) out_ << ";";
+												} else {
+													out_ << "G"; if (NResource::lilyProperties_.lilySemicolons) out_ << ";";
+												}
+											} else {
+												out_ << "violin"; if (NResource::lilyProperties_.lilySemicolons) out_ << ";";
+											}
+											break;
+					 case SOPRANO_CLEF:	switch (clef->getShift()) {
+								case -12:	out_ << "\"soprano_8\"";	break;
+								case  12:	out_ << "\"soprano^8\"";	break;
+								default:	out_ << "soprano";
+								}
+								if (NResource::lilyProperties_.lilySemicolons) out_ << ";"; break;
 					 case ALTO_CLEF: out_ << "alto"; if (NResource::lilyProperties_.lilySemicolons) out_ << ";"; break;
+					 case TENOR_CLEF: out_ << "tenor"; if (NResource::lilyProperties_.lilySemicolons) out_ << ";"; break;
 					 case DRUM_BASS_CLEF: out_ << "percussion"; if (NResource::lilyProperties_.lilySemicolons) out_ << ";"; break;
 					 case BASS_CLEF: out_ << "bass"; if (NResource::lilyProperties_.lilySemicolons) out_ << ";"; break;
 				     }
@@ -1421,7 +1590,7 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 				     break;
 			case T_SIGN: if (inGrace) {
 					inGrace = false;
-					if (!strokenGrace) {
+					if (!strokenGrace && !NResource::lilyProperties_.lilyVersion2) {
 						strokenGrace = false;
 						out_ << "] ";
 					}
@@ -1684,7 +1853,7 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 				     pending_text = (NText *) elem;
 				     break;
 				    
-		}
+		} // end switch (elem->getType())
 		elem = voi->getNextPosition();
 	}
 	while (elem);
@@ -1725,13 +1894,15 @@ void NLilyExport::writeChordName(QString chordname) {
 	}
 }
 
-void NLilyExport::writeLyrics(int voice_nr, NVoice *voi) {
+void NLilyExport::writeLyrics(int voice_nr, NVoice *voi, const QString& label) {
 	NMusElement *elem;
 	NChord *chord;
 	QString *ps, s;
 	int lyline;
 	int counter;
 
+if (NResource::lilyProperties_.lilyVersion24) {
+} else {
 	if (staffarray_[voice_nr].lyrics_count > 1) {
 		out_ << "{" << endl << "\t\\simultaneous {" << endl << "\t\t";
 		depth_ = 2;
@@ -1740,11 +1911,17 @@ void NLilyExport::writeLyrics(int voice_nr, NVoice *voi) {
 		out_ << "{" << endl << '\t';
 		depth_ = 1;
 	}
+}
 	
 	for (lyline = 0; lyline < staffarray_[voice_nr].lyrics_count; lyline++) {
 		counter = 0;
 		voi->prepareForWriting();
-		out_ << "{" << endl; depth_++; tabsOut();
+		if (NResource::lilyProperties_.lilyVersion24) {
+			out_ << label.latin1() << "Text" << char(lyline+'A') << " = \\lyricmode ";
+			out_ << "{" << endl; depth_++; tabsOut();
+		} else {
+			out_ << "{" << endl; depth_++; tabsOut();
+		}
 		elem = voi->getCurrentPosition();
 		while (elem) {
 			switch (elem->getType()) {
@@ -1766,6 +1943,7 @@ void NLilyExport::writeLyrics(int voice_nr, NVoice *voi) {
 				}
 				else {
 					s = QString(*ps);
+					s.replace(QChar('"'), "''");
 					s.replace(relSyms, "");
 					s.replace(whiteSpaces_, "_");
 					removeExceptsFromString(&s, true);
@@ -1786,14 +1964,199 @@ void NLilyExport::writeLyrics(int voice_nr, NVoice *voi) {
 			elem = voi->getNextPosition();
 		}
 		depth_--;
-		out_ << '}' << endl; tabsOut();
+		out_ << '}' << endl;
+		if (!NResource::lilyProperties_.lilyVersion24) tabsOut();
 	}
 	if (staffarray_[voice_nr].lyrics_count > 1) {
-		out_ << '}' << endl;
+		if (!NResource::lilyProperties_.lilyVersion24)
+			out_ << '}' << endl;
 	}
-	out_ << '}' << endl;
+	if (!NResource::lilyProperties_.lilyVersion24)
+		out_ << '}' << endl;
 }
 
+/*
+	Preparation where to begin and end a brace or bracket of the score.
+	For every staff a byte in QByteArray scoreBraceMasks is set with the bits
+	BRACE_START, BRACE_END, BRACKET_START and BRACKET_END according to the
+	partitur layout and the staffs selected. So in the follow up
+	buildScoreBlockAndFlush() can easily set Choir-/PianoStaff braces.
+*/
+
+void NLilyExport::buildBraceMasks(QList<NStaff> *stafflist, const NMainFrameWidget *mainWidget)
+{
+	NStaff *staff_el;
+	int m, mm, beg, end, nb;
+
+	const int nBraces = 2;		// bracket and brace are similar, so we prefer to loop.
+	layoutDef *bracs[nBraces];
+	char bracStart[nBraces];
+	char bracEnd[nBraces];
+	bracs[0]	= mainWidget->bracketMatrix_;
+	bracStart[0]	= BRACKET_START;
+	bracEnd[0]	= BRACKET_END;
+	bracs[1]	= mainWidget->braceMatrix_;
+	bracStart[1]	= BRACE_START;
+	bracEnd[1]	= BRACE_END;
+
+	scoreBraceMasks.fill(0,stafflist->count());	// adjust and fill target with zero
+	for (nb = 0; nb < nBraces; nb++) {
+		for (m = 0, staff_el = stafflist->first(); staff_el; staff_el = stafflist->next(), m++) {
+			if (bracs[nb][m].valid) {
+				beg = bracs[nb][m].beg;
+				end = bracs[nb][m].end;
+				for (mm = beg; mm <= end; mm++) {
+					if (staffarray_[mm].is_selected) {
+						scoreBraceMasks[mm] |= bracStart[nb];
+						break;
+					}
+				}
+				for (mm = end; mm >= beg; mm--) {
+					if (staffarray_[mm].is_selected) {
+						scoreBraceMasks[mm] |= bracEnd[nb];
+						break;
+}	}	}	}	}	} 
+
+
+/*
+	This function is called for every Staff, with parameter flush
+	beeing false. At the end of this a call with flush true is needed
+	to push everything out. The first Character of every line in scoreBlock
+	holds the number of tabs to get a nice printout of the hierachy.
+
+	NoteEdit allows to attach lyrics with one or multiple verses only
+	to the first voice of a stave.
+*/
+
+void NLilyExport::buildScoreBlockAndFlush(	int i, // staff index
+						NStaff *staff_elem,
+						const QString& label,
+						QList<NStaff> *stafflist,
+						const QByteArray braceMasks,
+						bool flush )
+{
+	unsigned int m;
+	double wh;
+	QString tmps, stanzaNStr;
+	static int hy;		// hierarchy, help determine indentation with tabs
+	static int ii, endDist;	// indices
+	static bool currentlyInGrandStaff, lyricsInGrandStaff;
+
+	if (flush) {		// Flush, initialize for a next export and return.
+        	if (!exportDialog_->lilyVoice->isChecked()) {
+			if (lyricsInGrandStaff) {
+				tmps.sprintf("2\\context { \\GrandStaff \\accepts Lyrics }\n");
+				scoreBlock.insert(scoreBlock.count()-2, new QString(tmps));
+			}
+			for (m=0;m<scoreBlock.count();m++) {
+	               		tmps.sprintf("%s", scoreBlock.at(m)->latin1());
+				depth_ = tmps[0].digitValue();		// flush tabs
+				tabsOut();
+	               		out_ << tmps.remove(0,1);		// and flush rest of line
+			}
+		}
+		scoreBlock.clear();	// autodelete is on, triggers init block next time
+		return;
+        }
+	
+	if (scoreBlock.isEmpty()) {	// This is the init block
+
+		scoreBlock.append( new QString("0\\score {\n"));
+		ii = 1;				// Index of the place for next insertion in hierarchy
+		scoreBlock.append( new QString("2\\set Score.skipBars = ##t\n"));	// closing first hy
+		scoreBlock.append( new QString("2\\set Score.melismaBusyProperties = #'()\n"));
+		scoreBlock.append( new QString("1>>\n"));
+
+		tmps.sprintf("1\\layout {%s\n",
+			exportDialog_->lilyLand->isChecked() ? " orientation = \"landscape\"" : "");
+		scoreBlock.append( new QString(tmps));
+		if (sscanf(exportDialog_->lilyWidth->text(), "%lf", &wh) != 1) wh = 250.0;
+		tmps.sprintf("2linewidth = %.3lf \\mm\n", wh );
+		scoreBlock.append( new QString(tmps));
+		if (sscanf(exportDialog_->lilyHeight->text(), "%lf", &wh) != 1) wh = 160.0;
+		tmps.sprintf("2textheight = %.3lf \\mm\n", wh );
+		scoreBlock.append( new QString(tmps));
+		scoreBlock.append( new QString("1}\n"));
+
+		scoreBlock.append( new QString("0}\n"));
+		hy = 1;
+		endDist = 8;
+		lyricsInGrandStaff = false;
+	}
+
+	if (hy==1) {						// Beginning of the block, hierachy is 1
+		tmps.sprintf("%d\\relative <<\n",			hy++ );
+		scoreBlock.insert(ii++, new QString(tmps));
+		currentlyInGrandStaff = false;
+	}
+
+	if (staffarray_[i].is_selected) {
+		if (scoreBraceMasks[i] & BRACE_START) {		// Piano/GrandStaff open, h++
+			tmps.sprintf("%d\\context GrandStaff = c%s%c <<\n", hy++, label.latin1(), i+'A');
+			scoreBlock.insert(ii++, new QString(tmps));
+			currentlyInGrandStaff = true;
+		}
+		if (scoreBraceMasks[i] & BRACKET_START) {	// ChoirStaff open
+			tmps.sprintf("%d\\context ChoirStaff = c%s%c <<\n", hy++, label.latin1(), i+'A');
+			scoreBlock.insert(ii++, new QString(tmps));
+		}
+
+		tmps.sprintf("%d\\context Staff = c%s%c <<\n", hy, label.latin1(), 0+'A');
+		scoreBlock.insert(ii++, new QString(tmps));
+
+		if (staff_elem->voiceCount() > 1) {
+			for (m=0;m<staff_elem->voiceCount();m++) {
+				tmps.sprintf("%d\\context Voice = c%sVoice%c \\%sVoice%c\n", hy+1, label.latin1(), m+'A',
+							label.latin1(), m+'A');
+				scoreBlock.insert(ii++, new QString(tmps));
+			}
+		} else {
+			// the last letter 'A' is a spare letter if you want to add more voices in the lily file
+			tmps.sprintf("%d\\context Voice = c%s%c \\%s\n", hy+1, label.latin1(), 0+'A', label.latin1());
+				scoreBlock.insert(ii++, new QString(tmps));
+		}
+
+		tmps.sprintf("%d>>\n", hy);
+		scoreBlock.insert(ii++, new QString(tmps));
+
+		for (m=0;m<staffarray_[i].lyrics_count;m++) {
+			if (staffarray_[i].lyrics_count>1)		// number only when 2 verses and more
+				stanzaNStr.sprintf("%d.", m+1);
+			else
+				stanzaNStr.sprintf("");
+			tmps.sprintf("%d\\context Lyrics = c%s%s%c { \\set stanza = \"%s\" }\n",
+				hy, label.latin1(),
+				staff_elem->voiceCount() > 1 ? "Voice" : "",
+				m+'A', stanzaNStr.latin1());
+
+			scoreBlock.insert(ii++, new QString(tmps));
+
+			tmps.sprintf("2\\context Lyrics = c%s%s%c \\lyricsto c%s%s%c \\%sText%c\n",
+				label.latin1(),
+				staff_elem->voiceCount() > 1 ? "Voice" : "",
+				m+'A', label.latin1(),
+				staff_elem->voiceCount() > 1 ? "Voice" : "",
+				0+'A',				// because of spare letter 'A'
+				label.latin1(), m+'A');
+			// Place of \lyricsto is before the last two braces:
+			scoreBlock.insert(scoreBlock.count()-endDist, new QString(tmps));
+
+			// remember to allow lyrics in GrandStaff context
+			lyricsInGrandStaff = lyricsInGrandStaff || currentlyInGrandStaff;
+		}
+
+		if (scoreBraceMasks[i] & BRACKET_END) {		// ChoirStaff close, hy--
+			tmps.sprintf("%d>>\n", --hy);
+			scoreBlock.insert(ii++, new QString(tmps));
+		}
+		if (scoreBraceMasks[i] & BRACE_END) {		// GrandStaff close
+			tmps.sprintf("%d>>\n", --hy);
+			scoreBlock.insert(ii++, new QString(tmps));
+			currentlyInGrandStaff = false;
+		}
+		scoreBlock.insert(ii++, new QString("0\n"));	// empty line
+	}
+}
 
 void NLilyExport::removeExceptsFromString(QString *str, bool onlyDigits) {
 	int l = str->length();
@@ -1810,8 +2173,8 @@ void NLilyExport::removeExceptsFromString(QString *str, bool onlyDigits) {
 		
 }
 		
-char *NLilyExport::LilyPondKeyName(int kind, int count) {
-	char *err = "LilyPondKeyName: internal error";
+const char *NLilyExport::LilyPondKeyName(int kind, int count) {
+	const char *err = "LilyPondKeyName: internal error";
 	if (kind == STAT_CROSS) {
 		switch (count) {
 			case 0: return "c";
