@@ -244,7 +244,7 @@ class NMainFrameWidget : public QWidget
 /*--------------------------- reaction on menu events -----------------------------------*/
 		void scoreInfo();
 		void configure();
-		void newPaper();
+		bool newPaper();
 		void openNewWindow();
 		void zoomIn();
 		void zoomOut();
@@ -331,6 +331,7 @@ class NMainFrameWidget : public QWidget
 		void KE_moveEnd();
 		void KE_moveRight();
 		void KE_delete();
+		void KE_play();
 		void KE_edit();
 		void KE_insertnote();
 		void KE_insertchordnote();
@@ -433,7 +434,7 @@ class NMainFrameWidget : public QWidget
 		KToggleAction *rectDrumBu_;
 		KToggleAction *triaDrumBu_;
 		NInfoTable *about_;
-		NDbufferWidget *notePart_;
+		NDbufferWidget *notePart_; //main view of the score
 		KAction *lilyPort_;
 		int voiceNr_;
 /*------------------------------ Dialogs ------------------------------------------------*/
@@ -460,7 +461,7 @@ class NMainFrameWidget : public QWidget
 		staffFrm *multistaffDialog_;
 		staffelFrm *clefDialog_;
 		staffPropFrm *staffPropFrm_;
-		voiceDiaFrm *voiceDialog_;
+//		voiceDiaFrm *voiceDialog_; //deprecated
 		tupletDialogImpl *tupletDialog_;
 
 		QDialog *keyDialog_;
@@ -557,8 +558,8 @@ class NMainFrameWidget : public QWidget
 		void writeTSE3();
 		void readTSE3();
 		void TSE3MidiOut();
-		void TSE3MidiIn();
-		void TSE3toScore();
+		bool TSE3MidiIn();
+		bool TSE3toScore();
 		void TSE3ParttoScore();
 		void TSE3Filter();
 		void completeRecording(bool);
@@ -594,7 +595,7 @@ class NMainFrameWidget : public QWidget
 		bool playing_;
 		NTempoTrack SortedTempoSigs_;
 		bool firstNoteActive_; // avoid overwriting first red colored note
-		bool playStop_;
+		bool playStop_; //stop playing
 		struct timeval nextPlayTime_;
 		static void add_time(struct timeval *res, struct timeval *now, long msecs);
 		unsigned long sub_time(struct timeval *future, struct timeval *now);
@@ -615,7 +616,7 @@ class NMainFrameWidget : public QWidget
 		QList<NMidiEventStr> stopList_;
 		void cleanupSelections();
 /*-------------------------------- static dadabase -------------------------------*/
-		static char *keySigTab_[15];
+		static const char *keySigTab_[15];
 };
 
 #ifdef WITH_DIRECT_PRINTING
