@@ -46,10 +46,11 @@
 // please study uiconnect before you make any clef changes!
 #define TREBLE_CLEF (1 << 0)
 #define BASS_CLEF (1 << 1)
-#define ALTO_CLEF (1 << 2)
-#define TENOR_CLEF (1 << 3)
-#define DRUM_CLEF (1 << 4)
-#define DRUM_BASS_CLEF (1 << 5)
+#define SOPRANO_CLEF (1 << 2)
+#define ALTO_CLEF (1 << 3)
+#define TENOR_CLEF (1 << 4)
+#define DRUM_CLEF (1 << 5)
+#define DRUM_BASS_CLEF (1 << 6)
 
 // signs:
 
@@ -130,6 +131,7 @@ class main_props_str {
 		int dotcount;
 		bool hidden;
 		bool tied;
+		bool triplet;
 		bool staccato;
 		bool sforzato;
 		bool portato;
@@ -192,6 +194,10 @@ class NNote {
 		char needed_acc;
 		char acc_TeX_pos;
 		unsigned int status;
+
+// definition of status bits in NMusElement::status_
+// TBD and also in NNote::status ?
+
 #define STAT_SINGLE_DOT   (1 << 0)
 #define STAT_DOUBLE_DOT   (1 << 1)
 #define DOT_MASK     (STAT_SINGLE_DOT | STAT_DOUBLE_DOT)
@@ -274,8 +280,10 @@ class NMusElement {
 		void change(NMusElement *elem);
 		unsigned int status_;
 		unsigned int status2_;
+// definition of status bits in NMusElement::status2_
 #define STAT2_PEDAL_ON (1 << 0)
 #define STAT2_PEDAL_OFF (1 << 1)
+#define STAT2_AUTO_TRIPLET (1 << 2)
 		int trill_;
 		int dynamic_;
 		int va_;
@@ -349,7 +357,7 @@ class NMusElement {
 		double tupm_; double tupn_;
 		double tupTeXn_;
 		int xstart_, xend_;
-		QList<NMusElement> *tupletList_;
+		QList<NMusElement> *tupletList_;	// all elements in this element's tuplet
 };
 
 #endif // MUSELEMENT_H
