@@ -50,7 +50,7 @@ Accents		supported: staccato, sforzato, portato, strong pizzicato, sforzando, fe
 			   arpeggio and pedal on/off
 Bar separators	supported: simple, double, end
 Beams		supported
-Clefs		supported: alto, bass, tenor and treble clef, not supported: drum and drum_bass clef
+Clefs		supported: treble, bass, soprano, alto and tenor clef, not supported: drum and drum_bass clef
 Clef change	supported
 Chords		supported
 Chord diagrams	supported, but excluding bass and degree
@@ -169,7 +169,11 @@ void NMusicXMLExport::debugDumpElem(NMusElement *elem) {
 			break;
 		case T_REST:
 			out_ << "T_REST";
-			out_ << " len=" << elem->getSubType();
+			if (elem->getSubType() == MULTIREST) {
+				out_ << " multilen=" << ((NRest *) elem)->getMultiRestLength();
+			} else {
+				out_ << " len=" << elem->getSubType();
+			}
 			break;
 		case T_SIGN:
 			out_ << "T_SIGN";
@@ -248,20 +252,34 @@ void NMusicXMLExport::debugDumpStaff(NStaff * staff_elem) {
 
 
 void NMusicXMLExport::debugDump(QList<NStaff> *stafflist, NMainFrameWidget *mainWidget) {
-	out_ << "scTitle=" << mainWidget->scTitle_ << endl;
-	out_ << "scSubtitle=" << mainWidget->scSubtitle_ << endl;
-	out_ << "scAuthor=" << mainWidget->scAuthor_ << endl;
-	out_ << "scLastAuthor=" << mainWidget->scLastAuthor_ << endl;
-	out_ << "scCopyright=" << mainWidget->scCopyright_ << endl;
-	out_ << "scComment=" << mainWidget->scComment_ << endl;
+	if (!mainWidget->scTitle_.isEmpty()) {
+		out_ << "scTitle=" << mainWidget->scTitle_ << endl;
+	}
+	if (!mainWidget->scSubtitle_.isEmpty()) {
+		out_ << "scSubtitle=" << mainWidget->scSubtitle_ << endl;
+	}
+	if (!mainWidget->scAuthor_.isEmpty()) {
+		out_ << "scAuthor=" << mainWidget->scAuthor_ << endl;
+	}
+	if (!mainWidget->scLastAuthor_.isEmpty()) {
+		out_ << "scLastAuthor=" << mainWidget->scLastAuthor_ << endl;
+	}
+	if (!mainWidget->scCopyright_.isEmpty()) {
+		out_ << "scCopyright=" << mainWidget->scCopyright_ << endl;
+	}
+	if (!mainWidget->scComment_.isEmpty()) {
+		out_ << "scComment=" << mainWidget->scComment_ << endl;
+	}
 	// staff list
 	NStaff *staff_elem;
 //	int staffcount;
 	int i;
 	for (i = 0, staff_elem = stafflist->first(); staff_elem; i++, staff_elem = stafflist->next()) {
-		out_ << "*** Staff " << i
-			<< " staffName=" << staff_elem->staffName_
-			<< " #voices="   << staff_elem->voiceCount()
+		out_ << "*** Staff " << i;
+		if (!staff_elem->staffName_.isEmpty()) {
+			out_ << " staffName=" << staff_elem->staffName_;
+		}
+		out_ << " #voices="   << staff_elem->voiceCount()
 			<< " midi-chn="  << staff_elem->getChannel()
 			<< " midi-pgm="  << staff_elem->getVoice()
 			<< endl;
@@ -656,6 +674,11 @@ bool NMusicXMLExport::writeFirstVoice(NVoice *voice_elem, int staff_nr) {
 					outputDots(rest);
 					outputTimeMod(rest);
 					bool needNotations = false;
+					bool fermata = false;
+					if (rest->status_ & STAT_FERMT) {
+						fermata = true;
+						needNotations = true;
+					}
 					bool tupletStart = false;
 					if ((rest->status_ & STAT_TUPLET)
 					     && rest->isFirstInTuplet()) {
@@ -663,12 +686,16 @@ bool NMusicXMLExport::writeFirstVoice(NVoice *voice_elem, int staff_nr) {
 						needNotations = true;
 					}
 					bool tupletStop = false;
-					if ((rest->status_ & STAT_LAST_TUPLET)) {
+					if (rest->status_ & STAT_LAST_TUPLET) {
 						tupletStop = true;
 						needNotations = true;
 					}
 					if (needNotations) {
 						out_ << "\t\t\t\t<notations>\n";
+						if (fermata) {
+							// LVIFIX: only upright fermata's are generated.
+							out_ << "\t\t\t\t\t<fermata type=\"upright\"/>\n";
+						}
 						if (tupletStop) {
 							out_ << "\t\t\t\t\t<tuplet type=\"stop\"/>\n";
 						}
@@ -816,6 +843,7 @@ bool NMusicXMLExport::writeOtherVoicesTill(int staff_nr, int voice_nr, NVoice *v
 				      break;
 			case T_REST:
 //				     out_ << "writeOtherVoicesTill T_REST" << endl;
+				     // LVIFIX: repair code duplication between this and previous "case T_REST:"
 				     rest = (NRest *) elem;
 				     if (rest->getSubType() == MULTIREST) {
 				        // LVIFIX: this should be reported
@@ -844,6 +872,11 @@ bool NMusicXMLExport::writeOtherVoicesTill(int staff_nr, int voice_nr, NVoice *v
 					outputDots(rest);
 					outputTimeMod(rest);
 					bool needNotations = false;
+					bool fermata = false;
+					if (rest->status_ & STAT_FERMT) {
+						fermata = true;
+						needNotations = true;
+					}
 					bool tupletStart = false;
 					if ((rest->status_ & STAT_TUPLET)
 					     && rest->isFirstInTuplet()) {
@@ -851,12 +884,16 @@ bool NMusicXMLExport::writeOtherVoicesTill(int staff_nr, int voice_nr, NVoice *v
 						needNotations = true;
 					}
 					bool tupletStop = false;
-					if ((rest->status_ & STAT_LAST_TUPLET)) {
+					if (rest->status_ & STAT_LAST_TUPLET) {
 						tupletStop = true;
 						needNotations = true;
 					}
 					if (needNotations) {
 						out_ << "\t\t\t\t<notations>\n";
+						if (fermata) {
+							// LVIFIX: only upright fermata's are generated.
+							out_ << "\t\t\t\t\t<fermata type=\"upright\"/>\n";
+						}
 						if (tupletStop) {
 							out_ << "\t\t\t\t\t<tuplet type=\"stop\"/>\n";
 						}
@@ -1023,6 +1060,7 @@ void NMusicXMLExport::writePendingSigns(int staff_nr) {
 			voiceStatList_->pendingClef = 0;
 		}
 		if (voiceStatList_->pendingMultiRest) {
+			// LVINOTE: if multirests can have fermatas, add support here
 			out_ << "\t\t\t\t<measure-style>\n";
 			out_ << "\t\t\t\t\t<multiple-rest>"
 				<< voiceStatList_->pendingMultiRest->getMultiRestLength()
@@ -1671,8 +1709,11 @@ void NMusicXMLExport::outputClefInfo(NClef *clef, int staff_nr) {
 	QString sign = "";
 	int line = 0;
 	switch (clef->getSubType()) {
-		case ALTO_CLEF:      sign="C"; line=3; break;
+		case TREBLE_CLEF:    sign="G"; line=2; break;
 		case BASS_CLEF:      sign="F"; line=4; break;
+		case SOPRANO_CLEF:   sign="C"; line=1; break;
+		case ALTO_CLEF:      sign="C"; line=3; break;
+		case TENOR_CLEF:     sign="C"; line=4; break;
 		case DRUM_CLEF:	     sign="TBD"; line=2; // LVIFIX
 				     bad = new badinfo(MUSICXML_ERRDRUM_CLEF, staff_nr, 0);
 				     badlist_.append(bad);
@@ -1681,8 +1722,6 @@ void NMusicXMLExport::outputClefInfo(NClef *clef, int staff_nr) {
 				     bad = new badinfo(MUSICXML_ERRDRUM_CLEF, staff_nr, 0);
 				     badlist_.append(bad);
 				     break;
-		case TENOR_CLEF:     sign="C"; line=4; break;
-		case TREBLE_CLEF:    sign="G"; line=2; break;
 		default:             NResource::abort("NMusicXMLExport::outputClefInfo");
 	}
 	// LVIFIX: add number= to clef when using multiple (combined) staffs as in piano music
