@@ -87,7 +87,7 @@ Accents		supported: staccato, sforzato, portato, strong pizzicato, sforzando, fe
 Accidentals	supported: sharp, flat and natural, including double sharp and flat
 Bar separators	supported: simple, double, end
 Beams		supported
-Clefs		supported: alto, bass, tenor and treble clef, not supported: drum and drum_bass clef
+Clefs		supported: treble, bass, soprano, alto and tenor clef, not supported: drum and drum_bass clef
 Clef change	supported
 Chords		supported
 Chord diagrams	supported, but excluding bass
@@ -651,9 +651,10 @@ bool MusicXMLParser::startElement( const QString&, const QString&,
 			Str = "ignoring unknown <slur> type: " + tp;
 			reportWarning(Str);
 		}
-	} else if (qName == "tied") {
-		// note: in MusicXML tie is for sound and tied for notation
-		// Noteedit does not make that distinction
+	// note: in MusicXML tie is for sound and tied for notation
+	// Noteedit does not make that distinction but responds
+	// to either one
+	} else if ((qName == "tie") || (qName == "tied")) {
 		QString tp = attributes.value("type");
 		if (tp == "start") {
 			stTie = true;
@@ -1786,6 +1787,8 @@ void MusicXMLParser::handleClef(NStaff *staff, QString& cli, QString& coc, QStri
 			kind = TREBLE_CLEF;
 		} else if ((csi == "F") && (cli == "4")) {
 			kind = BASS_CLEF;
+		} else if ((csi == "C") && (cli == "1")) {
+			kind = SOPRANO_CLEF;
 		} else if ((csi == "C") && (cli == "3")) {
 			kind = ALTO_CLEF;
 		} else if ((csi == "C") && (cli == "4")) {
