@@ -29,9 +29,9 @@
 #include <strstream.h>
 #endif
 #include <stdlib.h> //  esigra: needed for mkstemp when --without-libs
-#include <alloca.h>
+//#include <alloca.h>
 #include <kfiledialog.h>
-#include <alloca.h>
+//#include <alloca.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <ktextbrowser.h>
@@ -60,7 +60,6 @@
 #include "chorddiagram.h"
 #include "outputbox.h"
 #include "text.h"
-#include "musixhint.h"
 #include "multistaffinfo.h"
 #include "layout.h"
 
@@ -687,9 +686,6 @@ void NMusiXTeX::doExport() {
 	  externalCmd(exportDialog_->musixtexcmd->text(),fileName);
 	  NResource::musixScript_ = exportDialog_->musixtexcmd->text();
   	}
-	if (NResource::musixWarn_) {
-		NResource::musixHint_->show();
-	}
 	
 }
 
@@ -1146,6 +1142,11 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 								badMeasures_.append(exerr);
 					    break;
 			     }
+			     if(elem->status_ & STAT_FERMT) {
+				// LVIFIX does fermataup need a parameter and, if so, what should it be ?
+				// the "k" below is a random choice
+				out_ << "\\fermataup k";
+			     }
 			     if (elem->getSubType() == MULTIREST)
 				out_ << "\\Hpause32\\uptext{\\sk\\meterfont{" << ((NRest *)elem)->getMultiRestLength() << "}}\\sk\\sk\\hsk";
 			     else 
@@ -1275,11 +1276,14 @@ void NMusiXTeX::generate(int staff_nr, int real_staff_nr, const char *extraDelim
 			     if (barNr_ <= 2) break;
 			     staff_elem->actualClef_.change((NClef *) elem);
 			     switch(elem->getSubType()) {
+				case TREBLE_CLEF:
+					mStaffInf_->noticeClefChange(real_staff_nr, 0);
+			     		break;
 				case BASS_CLEF:
 					mStaffInf_->noticeClefChange(real_staff_nr, 6);
 			     		break;
-				case TREBLE_CLEF:
-					mStaffInf_->noticeClefChange(real_staff_nr, 0);
+				case SOPRANO_CLEF:
+					mStaffInf_->noticeClefChange(real_staff_nr, 1);
 			     		break;
 				case ALTO_CLEF:
 					mStaffInf_->noticeClefChange(real_staff_nr, 3);
@@ -1425,8 +1429,8 @@ QString NMusiXTeX::lyrics2TeX(QString *lyrics) {
 
 void NMusiXTeX::externalCmd (QString command, QString filename) {
   
-  // Fhre externes Command aus.
-  // Steht im Kommando ein "%f", ersetze es durch filename
+  // Execute external command.
+  // A "%f" in command is replaced by filename
   QRegExp reg = QRegExp("%f");
   QString setUserPath;
   QString destDir;
@@ -1453,7 +1457,7 @@ void NMusiXTeX::externalCmd (QString command, QString filename) {
   command.append(" >");
   command.append(tempDir);
   command.append(" 2>&1");
-  // Kdo ausfhren
+  // Execute kdo
   system (command.latin1());
 
   // Ausgabe aus Tmp-File zusammenfriemeln
