@@ -61,7 +61,6 @@
 #include "clef.h"
 #include "uiconnect.h"
 #include "lilytest.h"
-#include "musixhint.h"
 #define HELP_LINE_COLOR (20, 250, 20)
 #define DUMMY_NOTE_COLOR (100, 100, 100)
 #define DUMMY_NOTE_WIDTH 2
@@ -394,7 +393,6 @@ QPixmap *NResource::perTrianGreyPixmap_;
 
 QPixmap *NResource::musixwarn1_;
 QPixmap *NResource::musixwarn2_;
-NMusixHint *NResource::musixHint_;
 
 int       NResource::nbasePixmapHeight_;
 int       NResource::narrow_dist_;
@@ -450,7 +448,6 @@ unsigned int NResource::autosaveInterval_;
 unsigned int NResource::turnOverPoint_;
 
 //  Startup
-bool NResource::musixWarn_;
 bool NResource::startupLoadLastScore_;
 
 
@@ -472,7 +469,6 @@ int  NResource::overlength_ = DEFAULT_OVERLENGTH;
 int  NResource::schedulerRequest_ = ALL_SCHEDULERS;
 int  NResource::defZoomval_ = PREFERRED_ZOOM_VAL;
 staff_props_str NResource::nullprops_;
-main_props_str NResource::nullMainProps_;
 QList<NMainWindow> NResource::windowList_;
 NMidiMapper *NResource::mapper_;
 int NResource::lastWindowX_ = 0;
@@ -636,7 +632,6 @@ NResource::NResource() {
 		turnOverPoint_ = TURN_OVER_MIN;
 
 	kapp->config()->setGroup("Startup");
-	musixWarn_ = kapp->config()->readBoolEntry("MusixWarn", MUSIX_WARN);
 	startupLoadLastScore_ = kapp->config()->readBoolEntry
 		("LoadLastScore", STARTUP_LOAD_LAST_SCORE);
 
@@ -742,7 +737,6 @@ NResource::NResource() {
 	  );
 
 	kapp->config()->setGroup("Startup");
-	musixWarn_ = kapp->config()->readBoolEntry("MusixWarn", MUSIX_WARN);
 	startupLoadLastScore_ =
 		kapp->config()->readBoolEntry("LoadLastScore", STARTUP_LOAD_LAST_SCORE);
 
@@ -785,7 +779,7 @@ NResource::NResource() {
 
 	resourceDir_ = locate( "data", "noteedit/resources/" );
 	if (resourceDir_.isEmpty()) {
-		cerr << "Can't find apps/noteedit/resources. Check your installation and $KDEDIR if set" << endl;
+		cerr << "Can't find apps/noteedit/resources. Check your installation and $KDEDIR, if set" << endl;
 		exit(10);
 	}
 	fanfareFile_ = locate("data", "noteedit/resources/fanfare.mp3");
@@ -805,8 +799,8 @@ NResource::NResource() {
 	nullprops_.is_actual = false;
 	nullprops_.actual_keysig = 0;
 
-	nullKeySig_ = new NKeySig(&nullMainProps_, &nullprops_);
-	nullClef_ = new NClef(&nullMainProps_, &nullprops_);
+	nullKeySig_ = new NKeySig(0, &nullprops_);
+	nullClef_ = new NClef(0, &nullprops_);
 	QString s = resourceDir_;
 	progress_    = new KProgress;
 	progress_->setGeometry(40, 40, 200, 20);
@@ -942,20 +936,6 @@ NResource::NResource() {
 	cursor_quarternote_ = loadCursor("cursor_quarternote.xbm");
 	cursor_tinysixteenth_ = loadCursor("cursor_tinysixteenth.xbm");
 
-	musixHint_ = new NMusixHint();
-	s = resourceDir_ + QString("warn1.png");
-	musixwarn1_ = new QPixmap(s);
-	if (musixwarn1_->isNull()) {
-		sprintf (e, "Error in loading image [%s]",s.ascii());
-		abort(e);
-	}
-	s = resourceDir_ + QString("warn2.png");
-	musixwarn2_ = new QPixmap(s);
-	if (musixwarn2_->isNull()) {
-		sprintf (e, "Error in loading image [%s]",s.ascii());
-		abort(e);
-	}
-
 	naturPixWidth_ = naturPixmap_->width();
 	nbasePixmapHeight_ = nbasePixmap_->height();
 	nbasePixmapWidth2_ = nbasePixmap_->width() / 2;
@@ -1004,7 +984,6 @@ NResource::~NResource() {
 	kapp->config()->writeEntry(QString("TurnOver"), turnOverPoint_);
 
 	kapp->config()->setGroup("Startup");
-	kapp->config()->writeEntry(QString("MusixWarn"), musixWarn_);
 	kapp->config()->writeEntry(QString("LoadLastScore"), startupLoadLastScore_);
 
 
@@ -1089,6 +1068,34 @@ NResource::~NResource() {
 	
 }
 
+// Read toolbar settings from noteedit config file
+// toolBarIterator: Iterator over all toolbars from main windows
+void NResource::readToolbarSettings(QPtrListIterator<KToolBar> toolBarIterator)
+{
+    KToolBar *toolBar = 0;
+    kapp->config()->setGroup("ToolBar");
+    if( toolBarIterator.isEmpty() )
+      printf("Warning: No Toolbars\n");
+    for(toolBarIterator.toFirst(); toolBar = toolBarIterator.current(); ++toolBarIterator )
+    {
+      toolBar->applySettings(kapp->config(), QString("ToolBar ") + toolBar->name());
+    }
+}
+
+// Write toolbar settings to noteedit config file
+// toolBarIterator: Iterator over all toolbars from main windows
+void NResource::writeToolbarSettings(QPtrListIterator<KToolBar> toolBarIterator)
+{
+    KToolBar *toolBar = 0;
+    kapp->config()->setGroup("ToolBar");
+    if( toolBarIterator.isEmpty() )
+      printf("Warning: No Toolbars\n");
+    for(toolBarIterator.toFirst(); toolBar = toolBarIterator.current(); ++toolBarIterator )
+    {
+      toolBar->saveSettings(kapp->config(), QString("ToolBar ") + toolBar->name());
+    }
+}
+
 void NResource::autosave() {
 	NMainWindow *main_win;
 	int i;
