@@ -27,6 +27,7 @@
 #include "transpainter.h"
 #include "chord.h"
 #include "voicedialog.h"
+#include "staffPropFrm.h"
 #include <stdio.h>
 #include <kmessagebox.h>
 #include <klocale.h>
@@ -34,7 +35,7 @@
 #define OVER 10
 
 #define XLABEL_DIST 40
-#define YLABEL_DIST 20
+#define YLABEL_DIST 30
 
 NStaff::NStaff(int base, int midi_channel, int voice, NMainFrameWidget *mainWidget) : 
 actualKeysig_(&(mainWidget->main_props_) , &staff_props_),
@@ -168,7 +169,7 @@ NVoice *NStaff::deleteVoice(NVoice *oldVoice) {
 
 #else
 
-int NStaff::deleteVoice(NVoice *oldVoice, VoiceDialog *voicedialog) {
+int NStaff::deleteVoice(NVoice *oldVoice, VoiceDialog *voicedialog, staffPropFrm *staffPropForm) {
 	int voiceNr;
 	if (oldVoice->isFirstVoice()) {
 		KMessageBox::sorry
@@ -181,14 +182,24 @@ int NStaff::deleteVoice(NVoice *oldVoice, VoiceDialog *voicedialog) {
 	if ((voiceNr = voicelist_.find(oldVoice)) == -1) {
 		NResource::abort("NStaff::deleteVoice: internal error", 1);
 	}
-	if (KMessageBox::warningYesNo
-		(voicedialog,
-		 i18n("This deletes voice %1! Are you sure?").arg(voiceNr + 1),
-		 kapp->makeStdCaption(i18n("Delete voice")),
-		 i18n("&Delete")
-		)
-	    != KMessageBox::Yes
-	   ) return -1 ;
+	if( staffPropForm )
+		if (KMessageBox::warningYesNo
+			(staffPropForm,
+			i18n("This deletes voice %1! Are you sure?").arg(voiceNr + 1),
+			kapp->makeStdCaption(i18n("Delete voice")),
+			i18n("&Delete")
+			)
+		!= KMessageBox::Yes
+		) return -1 ;
+	else if( voicedialog )
+		if (KMessageBox::warningYesNo
+			(voicedialog,
+			i18n("This deletes voice %1! Are you sure?").arg(voiceNr + 1),
+			kapp->makeStdCaption(i18n("Delete voice")),
+			i18n("&Delete")
+			)
+		!= KMessageBox::Yes
+		) return -1 ;
 	voicelist_.remove();
 	if ((actualVoice_ = voicelist_.current()) == 0)  {
 		NResource::abort("NStaff::deleteVoice: internal error", 3);
@@ -346,6 +357,8 @@ void NStaff::transpose(int semitones) {
 	NVoice *voice_elem;
 	bool first;
 
+	if (semitones==0) return; //don't touch the score if transposing for 0 semitones
+	
 	if (actualVoiceNr_ == -1) {
 		for (voice_elem = voicelist_.first(), first = true; voice_elem; voice_elem = voicelist_.next(), first = false) {
 			if (NResource::windowWithSelectedRegion_ && voice_elem != NResource::voiceWithSelectedRegion_) {
@@ -504,7 +517,13 @@ void NStaff::gotoMarker(bool again) {
 	NVoice *voice_elem;
 	playClef_ = repeatClef_;
 	if (playKeySig_) {
-		delete playKeySig_;
+		/* This delete commented out fixes crash bug #3503, which hitted midi playing
+		and export whith multiple repeats. The tool pmem doesn't show a memory leak
+		caused by this. Similar constructs should come under investigation, see below?
+		The parameter "again" is set but not actually in use. 4/2005.
+		*/
+		// delete playKeySig_;
+		
 	}
 	playKeySig_ = repeatKeySig_;
 	voice_elem = voicelist_.first();
