@@ -158,8 +158,8 @@ void exportFrm::startExport() {
     }
 		
 
-    char *ext[] = { ".mid", ".tex", ".abc", ".pmx", ".ly", ".xml" };
-    char *desc[] = { "MIDI", "MusiXTeX", "ABC", "PMX",  "LilyPond",  "MusicXML"};
+    char *ext[] = { (char *)".mid", (char *)".tex", (char *)".abc", (char *)".pmx", (char *)".ly", (char *)".xml" };
+    char *desc[] = { (char *)"MIDI", (char *)"MusiXTeX", (char *)"ABC", (char *)"PMX",  (char *)"LilyPond", (char *)"MusicXML" };
 
 
     if( card->currentPageIndex() == MUSIX_PAGE || card->currentPageIndex() == LILY_PAGE ) {
@@ -200,24 +200,25 @@ void exportFrm::startExport() {
 
     if( !fileName.isNull() ) {
         switch( this->card->currentPageIndex() ) {
-    	    case MIDI_PAGE:    
+    	case MIDI_PAGE:    
     		me.exportMidi( fileName, voiceList_, (char *) this->midiInfo->text().ascii());
-		break;
+			break;
 	    case MUSIX_PAGE:  
-		mt.exportStaffs( fileName, staffList_, this,  mainWidget_);
-		break;
+			mt.exportStaffs( fileName, staffList_, this,  mainWidget_);
+			KMessageBox::information(this, i18n("MusiXTeX export is now complete.\nWarning! The exported file is NOT a LaTeX file! Please use musixtex or pmx parser for compilation and not latex!"), kapp->makeStdCaption(i18n("???")));
+			break;
 	    case ABC_PAGE:
-		abc.exportStaffs( fileName, staffList_, voiceList_->count(), this, mainWidget_ );
-		break;
+			abc.exportStaffs( fileName, staffList_, voiceList_->count(), this, mainWidget_ );
+			break;
 	    case MUSICXML_PAGE:
-		muxml.exportStaffs( fileName, staffList_, voiceList_->count(), this, mainWidget_ );
-		break;
+			muxml.exportStaffs( fileName, staffList_, voiceList_->count(), this, mainWidget_ );
+			break;
 	    case PMX_PAGE:
-		pe.exportStaffs( fileName, staffList_, this, mainWidget_ );
-		break;
+			pe.exportStaffs( fileName, staffList_, this, mainWidget_ );
+			break;
 	    case LILY_PAGE:
-		if( !NResource::lilyProperties_.lilyAvailable ) {
-	    if (KMessageBox::warningContinueCancel
+			if( !NResource::lilyProperties_.lilyAvailable ) {
+	    	if (KMessageBox::warningContinueCancel
 				(this,
 				 i18n("Actually LilyPond is not supported by your system. Do you realy want to make such an export?"),
 				 kapp->makeStdCaption(i18n("LilyPond export")),
@@ -229,9 +230,9 @@ void exportFrm::startExport() {
 				NResource::staffSelExport_ = 0;
 				return;
 			}
-		}
-		le.exportStaffs( fileName, staffList_, this , mainWidget_);
-		break;
+			}
+			le.exportStaffs( fileName, staffList_, this , mainWidget_);
+			break;
 	    }
 	this->close();
 	}
@@ -239,7 +240,7 @@ void exportFrm::startExport() {
 	delete [] NResource::staffSelExport_;
 	NResource::staffSelExport_ = 0;
 	}
-    }
+}
 
 void exportFrm::texMeasures() {
 
@@ -359,87 +360,6 @@ void exportFrm::setWithMeasureNums(bool with) {paramMeasureNums->setChecked(with
 void exportFrm::setSaveWidth(int width)  {pWidth->setValue(width);}
 void exportFrm::setSaveHeight(int height) {pHeight->setValue(height);}
 
-/*------------------------------------- staffPropsForm ------------------------------------------*/
-
-staffPropFrm::staffPropFrm(QWidget *parent)  : staffPropForm(parent, 0, true)
-{
-	for (int i = 0; i < 128; ++i)
-		staffVoice->insertItem(i18n("%1. %2").arg(i).arg(i18n(NResource::instrTab[i])));
-	for (int i = 0; i < 16; ++i)
-		staffChannel->insertItem(i18n("Channel %1").arg(i + 1 ));
-
-	this->staffVol->setAll(0, 127, 80);
-	this->staffOver->setAll(1, 200, 60);
-	this->staffUnder->setAll(1, 200, 60);
-	this->staffLyrics->setAll(1, 200, 60);
-	this->staffStereo->setAll(0, 127, 80);
-	this->staffReverb->setAll(0, 127, 0);
-	this->staffChorus->setAll(0, 127, 0);
-	this->staffPlay->setAll(-12, 17, 0);
-
-	mw_ = (NMainFrameWidget *) parent;
-	this->staffOk->setFocus();
-}
-
-void staffPropFrm::boot( NStaff *staff ) {
-
-    actualStaff_ = staff;
-    this->staffVol->setStartVal( values[0] =  actualStaff_->getVolume() );
-    this->staffOver->setStartVal( values[1] = actualStaff_->overlength_ );
-    this->staffUnder->setStartVal( values[2] = actualStaff_->underlength_ );
-    this->staffLyrics->setStartVal( values[3] = actualStaff_->staff_props_.lyricsdist );
-    this->staffStereo->setStartVal( values[4] = actualStaff_->pan_ );
-    this->staffReverb->setStartVal( values[5] = actualStaff_->reverb_ );
-    this->staffChorus->setStartVal( values[6] = actualStaff_->chorus_ );
-    this->staffChannel->setCurrentItem( values[7] = actualStaff_->getChannel() );
-    this->staffName->setText( actualStaff_->staffName_ );
-    this->staffVoice->setCurrentItem( values[8] = actualStaff_->getVoice() );
-    this->staffPlay->setStartVal( values[9] = actualStaff_->transpose_ );
-    this->show();
-    
-    }
-    
-void staffPropFrm::slotStaffCancel() {
-
-    this->close();
-    actualStaff_->setVolume( values[0] );
-    actualStaff_->overlength_ = values[1];
-    actualStaff_->underlength_ = values[2];
-    actualStaff_->staff_props_.lyricsdist = values[3];
-    actualStaff_->pan_ = values[4];
-    actualStaff_->reverb_ = values[5];
-    actualStaff_->chorus_ = values[6];
-    actualStaff_->setChannel( values[7] );
-    actualStaff_->changeVoice( values[8] );
-    actualStaff_->transpose_ = values[9];
-    mw_->arrangeStaffs(true);
-
-    }
-
-void staffPropFrm::slotStaffOk() {
-
-    refresh();
-    close();
-        
-    }
-    
-void staffPropFrm::refresh() {
-    
-    actualStaff_->setVolume( this->staffVol->getValue() );
-    actualStaff_->overlength_ = this->staffOver->getValue();
-    actualStaff_->underlength_ = this->staffUnder->getValue();
-    actualStaff_->staff_props_.lyricsdist = this->staffLyrics->getValue();
-    actualStaff_->pan_ = this->staffStereo->getValue();
-    actualStaff_->reverb_ = this->staffReverb->getValue();
-    actualStaff_->chorus_ = this->staffChorus->getValue();
-    actualStaff_->setChannel( this->staffChannel->currentItem() );
-    actualStaff_->staffName_ = QString( this->staffName->text() );
-    actualStaff_->changeVoice( this->staffVoice->currentItem() );
-    actualStaff_->transpose_ = this->staffPlay->getValue();
-    mw_->arrangeStaffs(true);
-
-    }
-
 /*----------------------------------------- scaleForm --------------------------------------------*/
 
 scaleFrm::scaleFrm( QWidget *parent ) : scaleForm( parent, 0, true ) {
@@ -615,8 +535,9 @@ void metronomFrm::abortSlot() {
 /*---------------------------------------- smallestRestForm -------------------------------------*/
 
 smallestRestFrm::smallestRestFrm( NMainFrameWidget *parent ) : clRestForm( parent, 0, true ) {
-	for (unsigned int i = 0; NResource::noteVal[i]; ++i)
-	this->sel->insertItem(i18n(NResource::noteVal[i]));
+	for (int i = 0; i < 12; ++i) {
+		this->sel->insertItem(i18n(NResource::noteVal[i]));
+	}
 	this->btOk->setFocus();
 }
 
@@ -673,8 +594,9 @@ int smallestRestFrm::item2length() {
 /*----------------------------------- volumeForm ------------------------------------------------*/
 
 volumeFrm::volumeFrm( QWidget *parent ) : volumeForm( parent, 0, true ) {
-	for (int i = 0; i < 8; ++i)
-	this->sel->insertItem(i18n(NResource::volume[i]));
+	for (int i = 0; i < 8; ++i) {
+		this->sel->insertItem(i18n(NResource::volume[i]));
+	}
 	this->btOk->setFocus();
 	this->scal_ed->setAll(0, 127, 100);
 }
@@ -950,7 +872,7 @@ staffFrm::staffFrm( QWidget *parent ) : staffForm( parent, 0, true ) {
 #undef isOn  /* setChecked and all "isOn" are redefined to "setChecked" which causes errors.(?) */
 
 void staffFrm::boot( QList<NStaff> *stafflist, char unsigned id, int amount ) {
-	char *na = I18N_NOOP("[not available]");
+	char *na = (char *)I18N_NOOP("[not available]");
 	this->elem->clear();
 	int i = 0;
 	if (amount)	staffAmount_ = amount;
@@ -1131,33 +1053,38 @@ void staffelFrm::slOk() {
     switch (type_) {
     	case IS_CLEF:
 		
-		if (selClass_->getSelection() < 12) {
-			if( selClass_->getSelection() > 3 ) oct = 8;
-			if( selClass_->getSelection() > 7 ) oct = -8;
+		/* WARNING: constants below depend on number of melodic/non-melodic clefs! For now, all melodic (octaviable) clefs appear at the beginning of list and non-melodic (non-octaviable) at the end. */
+		/* First we read and set clef octaviation, */
+		if (selClass_->getSelection() < 15) {
+			if( selClass_->getSelection() > 4 ) oct = 8;
+			if( selClass_->getSelection() > 9 ) oct = -8;
 		}
 		
-		if (selClass_->getSelection() < 12) {
-			mainWidget_->generateClef( ( 1 <<  ( selClass_->getSelection() % 4 ) ), oct );
+		/* then we read clefs for melodic intstruments ... */
+		if (selClass_->getSelection() < 15) {
+			mainWidget_->generateClef( ( 1 <<  ( selClass_->getSelection() % 5 ) ), oct );
 		}
+		/* or percussion clefs. */
 		else {
-			mainWidget_->generateClef( ( 1 <<  ( selClass_->getSelection() - 8 ) ), 0);
+			mainWidget_->generateClef( ( 1 <<  ( selClass_->getSelection() - 10 ) ), 0);
 		}
 		break;
 	case IS_CLEF_DISTANCE:
-		if (selClass_->getSelection() < 12) {
-			if( selClass_->getSelection() > 3 ) oct = 8;
-			if( selClass_->getSelection() > 7 ) oct = -8;
+		/* We do the same when changing the clef */
+		if (selClass_->getSelection() < 15) {
+			if( selClass_->getSelection() > 4 ) oct = 8;
+			if( selClass_->getSelection() > 9 ) oct = -8;
 		}
-		if (selClass_->getSelection() < 12) {
-			mainWidget_->performClefChange( ( 1 <<  ( selClass_->getSelection() % 4 )  ), oct );
+		if (selClass_->getSelection() < 15) {
+			mainWidget_->performClefChange( ( 1 <<  ( selClass_->getSelection() % 5 )  ), oct );
 		}
 		else {
-			mainWidget_->performClefChange( ( 1 <<  ( selClass_->getSelection() - 8 ) ), 0);
+			mainWidget_->performClefChange( ( 1 <<  ( selClass_->getSelection() - 10 ) ), 0);
 		}
 		break;
     	}
 
-    }
+	}
 
 void staffelFrm::slCh() {
 
@@ -1183,30 +1110,37 @@ timesigDiaFrm::timesigDiaFrm( NMainFrameWidget *mainWidget ) {
 }
 
 void timesigDiaFrm::showDialog() {
-	slNumerator->setStartVal(4);
-	slDnom->setStartVal(4);
 	show();
 }
 
-
 void timesigDiaFrm::slot_24() {
 	mainWidget_->setTempTimesig(2, 4);
+	slNumerator->setStartVal(2);
+	slDnom->setStartVal(4);
 	hide();
 }
 void timesigDiaFrm::slot_34() {
 	mainWidget_->setTempTimesig(3, 4);
+	slNumerator->setStartVal(3);
+	slDnom->setStartVal(4);
 	hide();
 }
 void timesigDiaFrm::slot_38() {
 	mainWidget_->setTempTimesig(3, 8);
+	slNumerator->setStartVal(3);
+	slDnom->setStartVal(8);
 	hide();
 }
 void timesigDiaFrm::slot_44() {
 	mainWidget_->setTempTimesig(4, 4);
+	slNumerator->setStartVal(4);
+	slDnom->setStartVal(4);
 	hide();
 }
 void timesigDiaFrm::slot_68() {
 	mainWidget_->setTempTimesig(6, 8);
+	slNumerator->setStartVal(6);
+	slDnom->setStartVal(8);
 	hide();
 }
 
