@@ -111,7 +111,7 @@ class NVoice {
 		bool inRepeat() {return endingIdx_ >= 0;}
 		bool muted_;
 		int stemPolicy_;
-/*------------------------ getting voice proerties ---------------------------------------*/
+/*------------------------ getting voice properties ---------------------------------------*/
 		main_props_str *getMainPropsAddr() {return main_props_;}
 		NStaff *getStaff() {return theStaff_;}
 		void printAll();
@@ -122,6 +122,7 @@ class NVoice {
 		int determineAnacrusis();
 		int getMidiTime() const;
 		int getMidiPos() const;
+		int getCurrentMeasureMidiLength();
 		int octave_;
 		bool voiceSet_;
 		int yRestOffs_;
@@ -325,7 +326,8 @@ class NVoice {
 /*------------------------------ voice properies -----------------------------------------*/
 		bool	firstVoice_;
 		QList<NMusElement> musElementList_;
-		NMusElement *currentElement_;
+		NMusElement *currentElement_;			// the selected element (drawn in red)
+								// if no element is selected, then 0
 		NMusElement *specialElement_;
 		NStaff  *theStaff_;
 /*-------------------------------- drawing voice ----------------------------------------------*/
@@ -356,7 +358,8 @@ class NVoice {
 		bool beameEndRequired(QList<NChord> *beamlist_so_far, NTimeSig *timesig, int beats);
 /*----------------------- dealing with tuplets -------------------------------------*/
 		void reconnectTuplets();
-
+		bool buildTupletList(int x0, int x1, char numNotes, QList<NMusElement> *elemlist);
+		void tryToBuildAutoTriplet();
 /*----------------------- search -------------------------------------*/
 		int searchPositionAndUpdateSigns(int dest_xpos, NMusElement **elem, bool *found, NMusElement **elem_before = 0, 
 			int *countof128th = 0, int *lastbaridx = 0, int *lastbarpos = 0, int *lastbartime = 0);
@@ -389,13 +392,15 @@ class NVoice {
 		main_props_str *main_props_;
 		QList<NMusElement> clipBoard_;
 		void eliminateRests(QList<NMusElement> *foundRests, int restSum, int over, NChord *lastChord);
-		void collectAndInsertPlayable(int startTime, QList<NMusElement> *patterns, int targetLength, bool useExistingElement);
+		void collectAndInsertPlayable(int startTime, QList<NMusElement> *patterns, int targetLength,
+			bool useExistingElement,
+			bool beforeBarSig = false );	// if true: first the short note, then the long one
 		static undostr undoelem_[MAXUNDO];
 		static undostr redoelem_[MAXUNDO];
 		NMidiEventStr midievents_[MIDI_EVENT_RING], *actualMidiEvent_;
 		NMainFrameWidget *mainWidget_;
-		NMusElement *startElement_, *endElement_;
-		int startElemIdx_, endElementIdx_;
+		NMusElement *startElement_, *endElement_;	// the selected region / marked block
+		int startElemIdx_, endElementIdx_;		// and corresponding index
 		static int undocounter_;
 		static int undoptr_, lastundoptr_;
 		static int redocounter_;
